@@ -1,4 +1,4 @@
-//$Id: dndwindow.cc,v 1.2 2003/01/23 12:03:46 murrayc Exp $ -*- c++ -*-
+//$Id: dndwindow.cc,v 1.3 2004/01/29 20:47:33 murrayc Exp $ -*- c++ -*-
 
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
@@ -59,19 +59,13 @@ DnDWindow::~DnDWindow()
 {
 }
 
-void DnDWindow::on_button_drag_data_get(const Glib::RefPtr<Gdk::DragContext>&, GtkSelectionData* selection_data, guint, guint)
+void DnDWindow::on_button_drag_data_get(const Glib::RefPtr<Gdk::DragContext>&, Gtk::SelectionData& selection_data, guint, guint)
 {
-  //TODO: The gtkmm API needs to change to use a Gtk::SelectionData instead of a GtkSelectionData.
-  //That should happen for gtkmm 2.4.
-  
-  gtk_selection_data_set (selection_data, selection_data->target, 8, (const guchar*)"I'm Data!", 9);
+  selection_data.set(selection_data.get_target(), 8 /* 8 bits format */, (const guchar*)"I'm Data!", 9 /* the length of I'm Data! in bytes */);
 }
 
 void DnDWindow::on_label_drop_drag_data_received(const Glib::RefPtr<Gdk::DragContext>& context, int, int, const Gtk::SelectionData& selection_data, guint, guint time)
-{
-  //TODO: The gtkmm API needs to change to use a Gtk::SelectionData instead of a GtkSelectionData.
-  //That should happen for gtkmm 2.4.
-  
+{ 
   if ((selection_data.get_length() >= 0) && (selection_data.get_format() == 8))
   {
     //TODO: Use a get_data_as_string or something like that.
