@@ -1,4 +1,4 @@
-//$Id: dndwindow.cc,v 1.12 2002/12/06 17:37:36 daniel Exp $ -*- c++ -*-
+//$Id: dndwindow.cc,v 1.3 2004/01/29 20:47:34 murrayc Exp $ -*- c++ -*-
 
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
@@ -98,11 +98,11 @@ DnDWindow::~DnDWindow()
 }
 
 
-void DnDWindow::on_label_drop_drag_data_received(const Glib::RefPtr<Gdk::DragContext>& context, int, int, GtkSelectionData* selection_data, guint, guint time)
+void DnDWindow::on_label_drop_drag_data_received(const Glib::RefPtr<Gdk::DragContext>& context, int, int, const Gtk::SelectionData& selection_data, guint, guint time)
 {
-  if ((selection_data->length >= 0) && (selection_data->format == 8))
+  if ((selection_data.get_length() >= 0) && (selection_data.get_format() == 8))
   {
-    g_print ("Received \"%s\" in label\n", (gchar *)selection_data->data);
+    g_print ("Received \"%s\" in label\n", (gchar *)selection_data.get_data());
   }
 
   context->drag_finish(false, false, time);
@@ -121,7 +121,7 @@ void DnDWindow::on_label_popup_drag_leave(const Glib::RefPtr<Gdk::DragContext>&,
  if (m_in_popup)
  {
    m_in_popup = false;
-   if (!m_popdown_timer)
+   if(!m_popdown_timer)
    {
      g_print ("added popdown\n");
      m_popdown_timer = Glib::signal_timeout().connect( SigC::slot(*this, &DnDWindow::on_popdown_timeout), 500);
@@ -129,11 +129,11 @@ void DnDWindow::on_label_popup_drag_leave(const Glib::RefPtr<Gdk::DragContext>&,
  }
 }
 
-void DnDWindow::on_image_drag_data_received(const Glib::RefPtr<Gdk::DragContext>& context, int, int, GtkSelectionData* selection_data, guint, guint time)
+void DnDWindow::on_image_drag_data_received(const Glib::RefPtr<Gdk::DragContext>& context, int, int, const Gtk::SelectionData& selection_data, guint, guint time)
 {
-  if ((selection_data->length >= 0) && (selection_data->format == 8))
+  if( (selection_data.get_length() >= 0) && (selection_data.get_format() == 8) )
   {
-    g_print ("Received \"%s\" in trashcan\n", (gchar*)selection_data->data);
+    g_print ("Received \"%s\" in trashcan\n", (gchar*)selection_data.get_data());
   }
 
   context->drag_finish(false, false, time);
@@ -191,14 +191,13 @@ bool DnDWindow::on_image_drag_drop(const Glib::RefPtr<Gdk::DragContext>& context
 }
 
 
-void DnDWindow::on_button_drag_data_get(const Glib::RefPtr<Gdk::DragContext>&, GtkSelectionData* selection_data, guint info, guint)
+void DnDWindow::on_button_drag_data_get(const Glib::RefPtr<Gdk::DragContext>&, Gtk::SelectionData& selection_data, guint info, guint)
 {
   if (info == TARGET_ROOTWIN)
     g_print ("I was dropped on the rootwin\n");
   else
-    gtk_selection_data_set (selection_data,
-                            selection_data->target,
-                            8, (const guchar*)"I'm Data!", 9);
+    selection_data.set(selection_data.get_target(),
+                       8 /* 8-bits format */, (const guchar*)"I'm Data!", 9 /* The length of I'm Data in bytes */);
 }
 
 void DnDWindow::on_button_drag_data_delete(const Glib::RefPtr<Gdk::DragContext>&)
